@@ -99,6 +99,11 @@ public:
         invalidateFilter();
     }
 
+    DiagnosticSeverity activeSeverity() const
+    {
+        return this->severity;
+    }
+
     bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override
     {
         bool ret = true;
@@ -110,6 +115,11 @@ public:
                 if (item->type() == DiagnosticItem_File) {
                     ret = static_cast<DocumentDiagnosticItem *>(item)->providers().contains(activeProvider);
                 } else {
+                    // check parent item if the item is not diag
+                    if (item->type() != DiagnosticItem_Diag && item->parent()) {
+                        Q_ASSERT(item->parent()->type() == DiagnosticItem_Diag);
+                        index = item->parent()->index();
+                    }
                     ret = index.data(DiagnosticModelRole::ProviderRole).value<DiagnosticsProvider *>() == activeProvider;
                 }
             }
@@ -132,11 +142,14 @@ public:
                     }
                 }
                 ret = count > 0;
-            } else if (item && item->type() == DiagnosticItem_Fix) {
+            } else if (item) {
+                ret = false;
                 if (item->parent() && item->parent()->type() == DiagnosticItem_Diag) {
                     auto castedItem = static_cast<DiagnosticItem *>(item);
                     ret = castedItem->m_diagnostic.severity == severity;
                 }
+            } else {
+                ret = false;
             }
         }
 
@@ -348,7 +361,7 @@ DiagnosticsView::DiagnosticsView(QWidget *parent, KTextEditor::MainWindow *mainW
         auto v = m_mainWindow->activeView();
         if (v) {
             if (auto doc = v->document()) {
-                syncDiagnostics(doc, v->cursorPosition().line(), true, false);
+                syncDiagnostics(doc, v->cursorPosition(), true, false);
             }
         }
     });
@@ -578,7 +591,7 @@ static DocumentDiagnosticItem *getItem(const QStandardItemModel &model, const QU
     return nullptr;
 }
 
-static QStandardItem *getItem(const QStandardItem *topItem, KTextEditor::Cursor pos, bool onlyLine)
+static QStandardItem *getItem(const QStandardItem *topItem, KTextEditor::Cursor pos, bool onlyLine, DiagnosticSeverity severity = DiagnosticSeverity::Unknown)
 {
     QStandardItem *targetItem = nullptr;
     if (topItem) {
@@ -613,8 +626,14 @@ static QStandardItem *getItem(const QStandardItem *topItem, KTextEditor::Cursor
             if (!(item->flags() & Qt::ItemIsEnabled)) {
                 continue;
             }
+
             auto range = item->data(DiagnosticModelRole::RangeRole).value<KTextEditor::Range>();
             if ((onlyLine && pos.line() == range.start().line()) || (range.contains(pos))) {
+                // the severity must match if it was specified
+                if (severity != DiagnosticSeverity::Unknown && item->type() == DiagnosticItem_Diag
+                    && static_cast<DiagnosticItem *>(item)->m_diagnostic.severity != severity) {
+                    continue;
+                }
                 targetItem = item;
                 break;
             }
@@ -863,7 +882,7 @@ void DiagnosticsView::onDiagnosticsAdded(const FileDiagnostics &diagnostics)
     // also sync updated diagnostic to current position
     auto currentView = m_mainWindow->activeView();
     if (topItem && currentView && currentView->document()) {
-        if (!syncDiagnostics(currentView->document(), currentView->cursorPosition().line(), false, false)) {
+        if (!syncDiagnostics(currentView->document(), currentView->cursorPosition(), false, false)) {
             // avoid jitter; only restore previous if applicable
             if (row >= 0 && row < topItem->rowCount()) {
                 m_diagnosticsTree->scrollTo(toProxyIndex(topItem->child(row)->index()));
@@ -1237,7 +1256,7 @@ void DiagnosticsView::goToItemLocation(QModelIndex index)
 void DiagnosticsView::onMarkClicked(KTextEditor::Document *document, KTextEditor::Mark mark, bool &handled)
 {
     // no action if no mark was sprinkled here
-    if (m_diagnosticsMarks.contains(document) && syncDiagnostics(document, mark.line, false, true)) {
+    if (m_diagnosticsMarks.contains(document) && syncDiagnostics(document, {mark.line, 0}, false, true)) {
         handled = true;
     }
 }
@@ -1260,12 +1279,14 @@ void DiagnosticsView::filterViewTo(DiagnosticsProvider *provider)
     }
 }
 
-bool DiagnosticsView::syncDiagnostics(KTextEditor::Document *document, int line, bool allowTop, bool doShow)
+bool DiagnosticsView::syncDiagnostics(KTextEditor::Document *document, KTextEditor::Cursor pos, bool allowTop, bool doShow)
 {
     auto hint = QAbstractItemView::PositionAtTop;
     DocumentDiagnosticItem *topItem = getItem(m_model, document->url());
     updateDiagnosticsSuppression(topItem, document);
-    QStandardItem *targetItem = getItem(topItem, {line, 0}, true);
+    auto proxy = static_cast<DiagnosticsProxyModel *>(m_proxy);
+    auto severity = proxy->activeSeverity();
+    QStandardItem *targetItem = getItem(topItem, pos, /*onlyLine=*/pos.column() == 0, severity);
     if (targetItem) {
         hint = QAbstractItemView::PositionAtCenter;
     }
@@ -1275,8 +1296,13 @@ bool DiagnosticsView::syncDiagnostics(KTextEditor::Document *document, int line,
     if (targetItem) {
         m_diagnosticsTree->blockSignals(true);
         const auto idx = m_proxy->mapFromSource(targetItem->index());
-        m_diagnosticsTree->scrollTo(idx, hint);
-        m_diagnosticsTree->setCurrentIndex(idx);
+        if (idx.isValid()) {
+            m_diagnosticsTree->scrollTo(idx, hint);
+            m_diagnosticsTree->setCurrentIndex(idx);
+        } else {
+            qWarning() << "Invalid idx for" << targetItem->text();
+            Q_ASSERT(false);
+        }
         m_diagnosticsTree->blockSignals(false);
         if (doShow) {
             m_mainWindow->showToolView(qobject_cast<QWidget *>(parent()));
