@@ -32,7 +32,6 @@
 #define HAVE_X11 __has_include(<KStartupInfo>)
 #if HAVE_X11
 #include <KStartupInfo>
-#include <KWindowInfo>
 #endif
 
 #ifdef WITH_KUSERFEEDBACK
@@ -190,6 +189,7 @@ KateApp::KateApp(const QCommandLineParser &args, const ApplicationMode mode, con
     , m_docManager(this)
     , m_sessionManager(this, sessionsDir)
     , m_stashManager(this)
+    , m_lastActivationChange(QDateTime::currentMSecsSinceEpoch())
 {
     /**
      * For Windows and macOS: use Breeze if available
@@ -518,24 +518,6 @@ KateStashManager *KateApp::stashManager()
     return &m_stashManager;
 }
 
-bool KateApp::isOnActivity(const QString &activity)
-{
-#if HAVE_X11
-    for (const auto window : qAsConst(m_mainWindows)) {
-        const KWindowInfo info(window->winId(), {}, NET::WM2Activities);
-        const auto activities = info.activities();
-        // handle special case of "on all activities"
-        if (activities.isEmpty() || activities.contains(activity)) {
-            return true;
-        }
-    }
-
-    return false;
-#else
-    return true;
-#endif
-}
-
 KTextEditor::Document *KateApp::openDocUrl(const QUrl &url, const QString &encoding, bool isTempFile, bool activateView, KTextEditor::Cursor c)
 {
     // temporary file handling
@@ -766,10 +748,15 @@ KTextEditor::Plugin *KateApp::plugin(const QString &name)
 
 bool KateApp::eventFilter(QObject *obj, QEvent *event)
 {
+    // keep track when we got activated last time
+    if (event->type() == QEvent::ActivationChange) {
+        m_lastActivationChange = QDateTime::currentMSecsSinceEpoch();
+    }
+
     /**
      * handle mac os like file open
      */
-    if (event->type() == QEvent::FileOpen) {
+    else if (event->type() == QEvent::FileOpen) {
         /**
          * try to open and activate the new document, like we would do for stuff
          * opened via dbus
